@@ -104,7 +104,6 @@ and data will start to show up in the Timestream table.
 
 Warning: this construct should be considered at alpha stage and is not feature complete.
 
-* Reduce Lambda log retention to 1d
 * Apply the least priviledge principle to roles
 * Implement updates for all the custom resources
 * Conditional campaigns
@@ -133,6 +132,7 @@ from ._jsii import *
 import aws_cdk
 import aws_cdk.aws_iam
 import aws_cdk.aws_lambda
+import aws_cdk.aws_logs
 import aws_cdk.aws_timestream
 import constructs
 
@@ -151,6 +151,7 @@ class Campaign(
         name: builtins.str,
         signals: typing.Sequence["CampaignSignal"],
         target: "Vehicle",
+        auto_approve: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
         :param scope: -
@@ -159,12 +160,14 @@ class Campaign(
         :param name: 
         :param signals: 
         :param target: 
+        :param auto_approve: 
         '''
         props = CampaignProps(
             collection_scheme=collection_scheme,
             name=name,
             signals=signals,
             target=target,
+            auto_approve=auto_approve,
         )
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -193,6 +196,7 @@ class Campaign(
         "name": "name",
         "signals": "signals",
         "target": "target",
+        "auto_approve": "autoApprove",
     },
 )
 class CampaignProps:
@@ -203,12 +207,14 @@ class CampaignProps:
         name: builtins.str,
         signals: typing.Sequence["CampaignSignal"],
         target: "Vehicle",
+        auto_approve: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
         :param collection_scheme: 
         :param name: 
         :param signals: 
         :param target: 
+        :param auto_approve: 
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "collection_scheme": collection_scheme,
@@ -216,6 +222,8 @@ class CampaignProps:
             "signals": signals,
             "target": target,
         }
+        if auto_approve is not None:
+            self._values["auto_approve"] = auto_approve
 
     @builtins.property
     def collection_scheme(self) -> "CollectionScheme":
@@ -241,6 +249,11 @@ class CampaignProps:
         assert result is not None, "Required property 'target' is missing"
         return typing.cast("Vehicle", result)
 
+    @builtins.property
+    def auto_approve(self) -> typing.Optional[builtins.bool]:
+        result = self._values.get("auto_approve")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -499,6 +512,11 @@ class SignalCatalog(
     def lambda_role(self) -> aws_cdk.aws_iam.Role:
         return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "lambdaRole"))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="logRetention")
+    def log_retention(self) -> aws_cdk.aws_logs.RetentionDays:
+        return typing.cast(aws_cdk.aws_logs.RetentionDays, jsii.get(self, "logRetention"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="name")
     def name(self) -> builtins.str:
